#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lens-action
version:              0.2.5
visibility:           public
id:                   lens-action-0.2.5-LuU4CHemPakGY34RGmwe4Q
key:                  lens-action-0.2.5-LuU4CHemPakGY34RGmwe4Q
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/lens-action/
synopsis:             Monadic Getters and Folds
description:
    This package contains combinators and types for working with
    monadic getters and folds as split off from the original
    lens package.

category:             Data, Lenses, Generics
abi:                  a604b6bf765a0d1209e5c893ec31d422
exposed:              True
exposed-modules:
    Control.Lens.Action Control.Lens.Action.Internal
    Control.Lens.Action.Reified Control.Lens.Action.Type

import-dirs:          /usr/lib/ghc-8.10.5/site-local/lens-action-0.2.5
library-dirs:         /usr/lib/ghc-8.10.5/site-local/lens-action-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/lens-action-0.2.5
hs-libraries:         HSlens-action-0.2.5-LuU4CHemPakGY34RGmwe4Q
depends:
    base-4.14.2.0 comonad-5.0.8-8a10YHmXJVq2BoDg3RtKOL
    contravariant-1.5.3-KWoYE9wiUjmElzHNq2wj10
    lens-5.0.1-7XUkI0pM5Tr3OUSblTWRuC mtl-2.2.2
    profunctors-5.6.2-HmnVxCk8JDbE3jxtqz7wd8
    semigroupoids-5.3.5-1MUCoMhFnfRKlT8x21E1a0 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-lens-action/html/lens-action.haddock
haddock-html:         /usr/share/doc/haskell-lens-action/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

